local human "AK"	// JH, AK, AM, etc
local index "gph"	//  gp, gph, gp_50_per_month, gpr_50_per_month, gp_blockade_months
local historical 1

local excel_files "U:\tf\GPR\GPR_human\audit_`index'\excel_coding_files\\`human'"
local stata_files "U:\tf\GPR\GPR_human\audit_`index'\stata_files\\`human'"
//local results_dir "U:\tf\Geopolitical_risk\GPR_DATA"

local partial 1 	// Set to 1 if you want to compile a partial result

cd `excel_files'
set more off
clear

**collect all the coded excel spreadsheets
local allfiles : dir . files "*_`human'.xls"
display `allfiles'

**turn each excel spreadsheet into a temporary stata file, save in new folder
foreach file in `allfiles' {
	cd `excel_files'
	import excel using "`file'", firstrow clear
	local temp = subinstr("`file'",".xls","",.)
	cd `stata_files'
	save `temp', replace
}

**collect all temporary stata files
cd `stata_files'
local statafiles : dir . files "*_`human'.dta"
clear

display `statafiles'

**create a blank variable to start a blank dataset that we will append to
gen blankvar = .
local full_name "`index'_`human'_full"
save `full_name', replace

**append each temporary stata file together
foreach dta in `statafiles' {
	use `full_name', clear
	append using `dta', force
	*capture drop Abstract
	save `full_name', replace
}

replace `human' = 0 if `human' == -1

**turn the file into a monthly human count
**gp gets a special case because the column title is different from the others
if "`index'" == "gp" {
	gen month = mofd(date(PublicationDate, "MDY"))
}
else {
	gen month = mofd(date(pubdate, "MDY"))
}
format month %tm
gen `index'_count = 1 //to get a total number of articles per month
bysort month (`human') : gen not_coded = mi(`human'[1]) //to identify which months have not been coded yet
if !`partial' {
	assert not_coded == 0 //if this fails, then there are uncoded months. Check those.
}
collapse (sum) `human' `index'_count not_coded, by(month) //creates the monthly count
replace `human' = . if not_coded != 0 //to make GPRH . instead of 0 for months that haven't been coded yet
drop not_coded
rename `human' `index'_`human'
save `full_name', replace
clear


/*

**get the GPR (for comparison) and GP (for calculating GPRH) from another file
cd `results_dir'

if `historical' {
	import excel using "gpr_historical_20180510.xlsx", sheet("GPRH") firstrow clear
	drop if mi(Year)
	gen m = mod(_n,12)
	replace m = 12 if m == 0
	gen y = int(Year)
	replace y = y + 1 if y < Year & m ==1
	gen month = mofd(mdy(m,1,y))
	format month %tm
	keep month GP
}
else {
	import excel using "gpr_index_20180510.xlsx", sheet("GPR") firstrow clear
	drop if mi(Date)
	gen month = mofd(Date)
	format month %tm
	keep month GP
}

**merge with the monthly human count
cd `stata_files'
merge 1:1 month using "`full_name'.dta"
drop _merge
order month `index'_`human' `index'_count GP

**generate GPRHuman
gen `index'_`human'_index = `index'_`human'/`index'_count*GP

if !`partial' {
	replace `index'_`human' = 0 if mi(`index'_`human')
	replace `index'_count = 0 if mi(`index'_count)
}

format month %tm
save `index'_`human'_monthly_data, replace
